import { addSchema } from "@kubernetes-models/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@kubernetes-models/base";
import { register } from "@kubernetes-models/validate";
const schemaId = "gateway.networking.k8s.io.v1beta1.Gateway";
const schema = {
    "type": "object",
    "properties": {
        "apiVersion": {
            "type": "string",
            "enum": [
                "gateway.networking.k8s.io/v1beta1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "Gateway"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        },
        "spec": {
            "properties": {
                "addresses": {
                    "items": {
                        "properties": {
                            "type": {
                                "default": "IPAddress",
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^Hostname|IPAddress|NamedAddress|[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*\\/[A-Za-z0-9\\/\\-._~%!$&'()*+,;=:]+$",
                                "nullable": true
                            },
                            "value": {
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string"
                            }
                        },
                        "required": [
                            "value"
                        ],
                        "type": "object"
                    },
                    "maxItems": 16,
                    "type": "array",
                    "nullable": true
                },
                "gatewayClassName": {
                    "maxLength": 253,
                    "minLength": 1,
                    "type": "string"
                },
                "listeners": {
                    "items": {
                        "properties": {
                            "allowedRoutes": {
                                "default": {
                                    "namespaces": {
                                        "from": "Same"
                                    }
                                },
                                "properties": {
                                    "kinds": {
                                        "items": {
                                            "properties": {
                                                "group": {
                                                    "default": "gateway.networking.k8s.io",
                                                    "maxLength": 253,
                                                    "type": "string",
                                                    "pattern": "^$|^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                                    "nullable": true
                                                },
                                                "kind": {
                                                    "maxLength": 63,
                                                    "minLength": 1,
                                                    "type": "string",
                                                    "pattern": "^[a-zA-Z]([-a-zA-Z0-9]*[a-zA-Z0-9])?$"
                                                }
                                            },
                                            "required": [
                                                "kind"
                                            ],
                                            "type": "object"
                                        },
                                        "maxItems": 8,
                                        "type": "array",
                                        "nullable": true
                                    },
                                    "namespaces": {
                                        "default": {
                                            "from": "Same"
                                        },
                                        "properties": {
                                            "from": {
                                                "default": "Same",
                                                "enum": [
                                                    "All",
                                                    "Selector",
                                                    "Same"
                                                ],
                                                "type": "string",
                                                "nullable": true
                                            },
                                            "selector": {
                                                "properties": {
                                                    "matchExpressions": {
                                                        "items": {
                                                            "properties": {
                                                                "key": {
                                                                    "type": "string"
                                                                },
                                                                "operator": {
                                                                    "type": "string"
                                                                },
                                                                "values": {
                                                                    "items": {
                                                                        "type": "string"
                                                                    },
                                                                    "type": "array",
                                                                    "nullable": true
                                                                }
                                                            },
                                                            "required": [
                                                                "key",
                                                                "operator"
                                                            ],
                                                            "type": "object"
                                                        },
                                                        "type": "array",
                                                        "nullable": true
                                                    },
                                                    "matchLabels": {
                                                        "additionalProperties": {
                                                            "type": "string"
                                                        },
                                                        "type": "object",
                                                        "properties": {},
                                                        "nullable": true
                                                    }
                                                },
                                                "type": "object",
                                                "nullable": true
                                            }
                                        },
                                        "type": "object",
                                        "nullable": true
                                    }
                                },
                                "type": "object",
                                "nullable": true
                            },
                            "hostname": {
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^(\\*\\.)?[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                "nullable": true
                            },
                            "name": {
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$"
                            },
                            "port": {
                                "format": "int32",
                                "type": "integer",
                                "minimum": 1,
                                "maximum": 65535
                            },
                            "protocol": {
                                "maxLength": 255,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^[a-zA-Z0-9]([-a-zSA-Z0-9]*[a-zA-Z0-9])?$|[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*\\/[A-Za-z0-9]+$"
                            },
                            "tls": {
                                "properties": {
                                    "certificateRefs": {
                                        "items": {
                                            "properties": {
                                                "group": {
                                                    "default": "",
                                                    "maxLength": 253,
                                                    "type": "string",
                                                    "pattern": "^$|^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                                    "nullable": true
                                                },
                                                "kind": {
                                                    "default": "Secret",
                                                    "maxLength": 63,
                                                    "minLength": 1,
                                                    "type": "string",
                                                    "pattern": "^[a-zA-Z]([-a-zA-Z0-9]*[a-zA-Z0-9])?$",
                                                    "nullable": true
                                                },
                                                "name": {
                                                    "maxLength": 253,
                                                    "minLength": 1,
                                                    "type": "string"
                                                },
                                                "namespace": {
                                                    "maxLength": 63,
                                                    "minLength": 1,
                                                    "type": "string",
                                                    "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?$",
                                                    "nullable": true
                                                }
                                            },
                                            "required": [
                                                "name"
                                            ],
                                            "type": "object"
                                        },
                                        "maxItems": 64,
                                        "type": "array",
                                        "nullable": true
                                    },
                                    "mode": {
                                        "default": "Terminate",
                                        "enum": [
                                            "Terminate",
                                            "Passthrough"
                                        ],
                                        "type": "string",
                                        "nullable": true
                                    },
                                    "options": {
                                        "additionalProperties": {
                                            "maxLength": 4096,
                                            "minLength": 0,
                                            "type": "string"
                                        },
                                        "maxProperties": 16,
                                        "type": "object",
                                        "properties": {},
                                        "nullable": true
                                    }
                                },
                                "type": "object",
                                "nullable": true
                            }
                        },
                        "required": [
                            "name",
                            "port",
                            "protocol"
                        ],
                        "type": "object"
                    },
                    "maxItems": 64,
                    "minItems": 1,
                    "type": "array"
                }
            },
            "required": [
                "gatewayClassName",
                "listeners"
            ],
            "type": "object"
        },
        "status": {
            "default": {
                "conditions": [
                    {
                        "lastTransitionTime": "1970-01-01T00:00:00Z",
                        "message": "Waiting for controller",
                        "reason": "NotReconciled",
                        "status": "Unknown",
                        "type": "Scheduled"
                    }
                ]
            },
            "properties": {
                "addresses": {
                    "items": {
                        "properties": {
                            "type": {
                                "default": "IPAddress",
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^Hostname|IPAddress|NamedAddress|[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*\\/[A-Za-z0-9\\/\\-._~%!$&'()*+,;=:]+$",
                                "nullable": true
                            },
                            "value": {
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string"
                            }
                        },
                        "required": [
                            "value"
                        ],
                        "type": "object"
                    },
                    "maxItems": 16,
                    "type": "array",
                    "nullable": true
                },
                "conditions": {
                    "default": [
                        {
                            "lastTransitionTime": "1970-01-01T00:00:00Z",
                            "message": "Waiting for controller",
                            "reason": "NotReconciled",
                            "status": "Unknown",
                            "type": "Scheduled"
                        }
                    ],
                    "items": {
                        "properties": {
                            "lastTransitionTime": {
                                "format": "date-time",
                                "type": "string"
                            },
                            "message": {
                                "maxLength": 32768,
                                "type": "string"
                            },
                            "observedGeneration": {
                                "format": "int64",
                                "type": "integer",
                                "minimum": 0,
                                "nullable": true
                            },
                            "reason": {
                                "maxLength": 1024,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^[A-Za-z]([A-Za-z0-9_,:]*[A-Za-z0-9_])?$"
                            },
                            "status": {
                                "enum": [
                                    "True",
                                    "False",
                                    "Unknown"
                                ],
                                "type": "string"
                            },
                            "type": {
                                "maxLength": 316,
                                "type": "string",
                                "pattern": "^([a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*\\/)?(([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9])$"
                            }
                        },
                        "required": [
                            "lastTransitionTime",
                            "message",
                            "reason",
                            "status",
                            "type"
                        ],
                        "type": "object"
                    },
                    "maxItems": 8,
                    "type": "array",
                    "nullable": true
                },
                "listeners": {
                    "items": {
                        "properties": {
                            "attachedRoutes": {
                                "format": "int32",
                                "type": "integer"
                            },
                            "conditions": {
                                "items": {
                                    "properties": {
                                        "lastTransitionTime": {
                                            "format": "date-time",
                                            "type": "string"
                                        },
                                        "message": {
                                            "maxLength": 32768,
                                            "type": "string"
                                        },
                                        "observedGeneration": {
                                            "format": "int64",
                                            "type": "integer",
                                            "minimum": 0,
                                            "nullable": true
                                        },
                                        "reason": {
                                            "maxLength": 1024,
                                            "minLength": 1,
                                            "type": "string",
                                            "pattern": "^[A-Za-z]([A-Za-z0-9_,:]*[A-Za-z0-9_])?$"
                                        },
                                        "status": {
                                            "enum": [
                                                "True",
                                                "False",
                                                "Unknown"
                                            ],
                                            "type": "string"
                                        },
                                        "type": {
                                            "maxLength": 316,
                                            "type": "string",
                                            "pattern": "^([a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*\\/)?(([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9])$"
                                        }
                                    },
                                    "required": [
                                        "lastTransitionTime",
                                        "message",
                                        "reason",
                                        "status",
                                        "type"
                                    ],
                                    "type": "object"
                                },
                                "maxItems": 8,
                                "type": "array"
                            },
                            "name": {
                                "maxLength": 253,
                                "minLength": 1,
                                "type": "string",
                                "pattern": "^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$"
                            },
                            "supportedKinds": {
                                "items": {
                                    "properties": {
                                        "group": {
                                            "default": "gateway.networking.k8s.io",
                                            "maxLength": 253,
                                            "type": "string",
                                            "pattern": "^$|^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$",
                                            "nullable": true
                                        },
                                        "kind": {
                                            "maxLength": 63,
                                            "minLength": 1,
                                            "type": "string",
                                            "pattern": "^[a-zA-Z]([-a-zA-Z0-9]*[a-zA-Z0-9])?$"
                                        }
                                    },
                                    "required": [
                                        "kind"
                                    ],
                                    "type": "object"
                                },
                                "maxItems": 8,
                                "type": "array"
                            }
                        },
                        "required": [
                            "attachedRoutes",
                            "conditions",
                            "name",
                            "supportedKinds"
                        ],
                        "type": "object"
                    },
                    "maxItems": 64,
                    "type": "array",
                    "nullable": true
                }
            },
            "type": "object",
            "nullable": true
        }
    },
    "required": [
        "spec",
        "apiVersion",
        "kind"
    ]
};
/**
 * Gateway represents an instance of a service-traffic handling infrastructure by binding Listeners to a set of IP addresses.
 */
export class Gateway extends Model {
    constructor(data) {
        super({
            apiVersion: Gateway.apiVersion,
            kind: Gateway.kind,
            ...data
        });
    }
}
Gateway.apiVersion = "gateway.networking.k8s.io/v1beta1";
Gateway.kind = "Gateway";
Gateway.is = createTypeMetaGuard(Gateway);
setSchema(Gateway, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
